/*
 * Copyright 2003, 2004 Berend "Kirk" Wouda
 *
 * This file is part of JavaDoctor.
 *
 * JavaDoctor is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * JavaDoctor is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JavaDoctor; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// La package.
package gui;

// We need this shit.
import java.awt.*;
import java.awt.event.ActionListener;

// Import my LayoutManager.
import kirk.gui.layout.GridSpanConstraints;
import kirk.gui.layout.GridSpanLayout;

/**
 * This class is the panel with the Convert and List Files buttons on it.
 *
 * @author Berend "Kirk" Wouda
 * @version 1.02
 * @since 1.00
 */
public class ButtonPanel extends Panel {
	/**
	 * Constructs and initialises a new ButtonPanel.
	 *
	 * @param listener The ActionListener for the buttons.
	 */
	public ButtonPanel(ActionListener listener) {
		// Call the super method.
		super();

		// Set the LayoutManager to GridSpanLayout.
		setLayout(new GridSpanLayout(1, 5));

		// The GridSpanConstraints object we are going to use for constrained
		// adding.
		GridSpanConstraints constraints;

		// Add the List Files button. Register listener as its actionlistener.
		// Put it in the upper two cells.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(0);
		constraints.setWidth(1);
		constraints.setHeight(2);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(0.5);
		Button listButton = new Button("List Files");
		listButton.setActionCommand("LISTFILES");
		listButton.addActionListener(listener);
		add(listButton, constraints);

		// Add the Convert button. Register listener as its actionlistener.
		// Put it in the next two cells.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(2);
		constraints.setWidth(1);
		constraints.setHeight(2);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(0.5);
		Button convertButton = new Button("Convert");
		convertButton.setActionCommand("CONVERT");
		convertButton.addActionListener(listener);
		add(convertButton, constraints);

		// Add the star insets checkbox.
		// Put it in the last cell.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(4);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalAnchor(0.0);
		constraints.setVerticalAnchor(0.0);
		add(starcheckbox, constraints);
	}


	/**
	 * Returns whether the star insets style of commentins should be used.
	 *
	 * @return Whether the star insets style of commentins should be used.
	 */
	public boolean getStarInsets() {
		// Retrieve the star inset setting from the button panel, and return that.
		return starcheckbox.getState();
	}


	/**
	 * The checkbox where the user can indicate whether the output folder is the same
	 * as the input folder.
	 * Give it a label, and set it to be standard on.
	 */
	protected Checkbox starcheckbox = new Checkbox("Use star insets in comment", true);
}