/*
 * Copyright 2003, 2004 Berend "Kirk" Wouda
 *
 * This file is part of JavaDoctor.
 *
 * JavaDoctor is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * JavaDoctor is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JavaDoctor; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// Teh package.
package gui;

// Import the GUI stuff.
import java.awt.*;

// My kickass LayoutManager.
import kirk.gui.layout.GridSpanConstraints;
import kirk.gui.layout.GridSpanLayout;

/**
 * This class is the panel with the Input and Output folder fields on it.
 *
 * @author Berend "Kirk" Wouda
 * @version 1.02
 * @since 1.00
 */
public class FolderPanel extends Panel {
	/**
	 * Constructs a new FolderPanel with all it's components and stuff.
	 */
	public FolderPanel() {
		// Call the super method.
		super();

		// Set the LayoutManager to GridSpanLayout.
		setLayout(new GridSpanLayout(1, 5));

		// The GridSpanConstraints object we are going to use for constrained
		// adding.
		GridSpanConstraints constraints;

		// Add the Input Folder label.
		// Put it in the first cell.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(0);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalAnchor(0.0);
		constraints.setVerticalAnchor(1.0);
		add(new Label("Input Folder:"), constraints);

		// Add the inputfolder textfield.
		// Put it in the second cell.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(1);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalAnchor(0.0);
		add(inputfolder, constraints);

		// Add the Output Folder label.
		// Put it in the third cell.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(2);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalAnchor(0.0);
		constraints.setVerticalAnchor(1.0);
		add(new Label("Output Folder:"), constraints);

		// Add the outputfolder textfield.
		// Put it in the fourth cell.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(3);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalAnchor(0.0);
		add(outputfolder, constraints);

		// Add the outputfolder same as inputfolder checkbox.
		// Put it in the fifth and last cell.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(4);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalAnchor(0.0);
		constraints.setVerticalAnchor(0.0);
		add(outputcheckbox, constraints);
	}


	/**
	 * Returns the Input Folder that the user has chosen.
	 *
	 * @return The Input Folder given by the user.
	 */
	public String getInputFolder() {
		// Return the contents of the inputfolder field.
		return inputfolder.getText();
	}

	/**
	 * Returns the Output Folder that the user has chosen.
	 *
	 * @return The Output Folder given by the user.
	 */
	public String getOutputFolder() {
		// Return the contents of the outputfolder field.
		return outputfolder.getText();
	}

	/**
	 * Returns whether the user wants to have the Output Folder the same as the
	 * Input Folder
	 *
	 * @return Whether the user wants to have the Output Folder the same as the
	 * Input Folder
	 */
	public boolean outputFolderIsInputFolder() {
		// Return the value from the checkbox.
		return outputcheckbox.getState();
	}


	/**
	 * The text field where the user can fill in the input folder.
	 */
	protected TextField inputfolder = new TextField();

	/**
	 * The text field where the user can fill in the output folder.
	 */
	protected TextField outputfolder = new TextField();

	/**
	 * The checkbox where the user can indicate whether the output folder is the same
	 * as the input folder.
	 * Give it a label, and set it to be standard on.
	 */
	protected Checkbox outputcheckbox = new Checkbox("Same as input folder", true);
}