/*
 * Copyright 2003, 2004 Berend "Kirk" Wouda
 *
 * This file is part of JavaDoctor.
 *
 * JavaDoctor is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * JavaDoctor is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JavaDoctor; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// La package.
package gui;

// We need this shit.
import java.awt.*;
import java.awt.event.ActionListener;

// My w00tass LayoutManager.
import kirk.gui.layout.GridSpanConstraints;
import kirk.gui.layout.GridSpanLayout;

/**
 * This class is the panel with the files List on it, as well as some list
 * manipulation buttons.
 *
 * @author Berend "Kirk" Wouda
 * @version 1.02
 * @since 1.00
 */
public class ListPanel extends Panel {
	/**
	 * Constructs and initialises a new ListPanel.
	 *
	 * @param listener The ActionListener for the buttons.
	 */
	public ListPanel(ActionListener listener) {
		// Call the super method.
		super();

		// Set the LayoutManager to GridSpanLayout.
		setLayout(new GridSpanLayout(2, 5));

		// The GridSpanConstraints object we are going to use for constrained
		// adding.
		GridSpanConstraints constraints;

		// Add the List. Allow it to have multiple selections.
		// Set it to fill the upper 4 rows and both columns.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(0);
		constraints.setWidth(2);
		constraints.setHeight(4);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		filelist.setMultipleMode(true);
		add(filelist, constraints);

		// Add the Select All button. Register listener as its actionlistener.
		// Put it in the left lower cell.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(4);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalAnchor(0.0);
		Button listButton = new Button("Select All");
		listButton.setActionCommand("SELECTALL");
		listButton.addActionListener(listener);
		add(listButton, constraints);

		// Add the Select None button. Register listener as its actionlistener.
		// Put it in the left lower cell.
		constraints = new GridSpanConstraints();
		constraints.setX(1);
		constraints.setY(4);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalAnchor(0.0);
		Button convertButton = new Button("Select None");
		convertButton.setActionCommand("SELECTNONE");
		convertButton.addActionListener(listener);
		add(convertButton, constraints);
	}


	/**
	 * Returns a list of the selected filenames.
	 *
	 * @return A list of the selected filenames.
	 */
	public String[] getFileList() {
		// Return the list of selected filenames.
		return filelist.getSelectedItems();
	}

	/**
	 * Set the list of the filenames to the passed filenames.
	 *
	 * @param filenamelist A list of filenames.
	 */
	public void setFileList(String[] filenamelist) {
		// Remove all the items from the list.
		filelist.removeAll();

		// Go through the list of filenames.
		for(int index = 0; index < filenamelist.length; index++) {
			// Add the current filename to filelist.
			filelist.add(filenamelist[index]);
		}
	}


	/**
	 * Selects all the files in the list of files.
	 */
	public void selectAllFiles() {
		// Go through the list.
		for(int index = 0; index < filelist.getItemCount(); index++) {
			// Select the current item.
			filelist.select(index);
		}
	}

	/**
	 * Deselects all the files in the list of files.
	 */
	public void deselectAllFiles() {
		// Go through the list.
		for(int index = 0; index < filelist.getItemCount(); index++) {
			// Select the current item.
			filelist.deselect(index);
		}
	}


	/**
	 * The list of files in the current folder.
	 */
	protected List filelist = new List();
}