/*
 * Copyright 2003, 2004 Berend "Kirk" Wouda
 *
 * This file is part of JavaDoctor.
 *
 * JavaDoctor is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * JavaDoctor is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JavaDoctor; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// La package.
package gui;

// We need this shit.
import java.awt.*;
import java.awt.event.ActionListener;

// Import mah LayoutManager.
import kirk.gui.layout.GridSpanConstraints;
import kirk.gui.layout.GridSpanLayout;

/**
 * This class is the panel with the tag stuff on it, like a list with some
 * manipulative buttons, some choices, and a label.
 *
 * @author Berend "Kirk" Wouda
 * @version 1.02
 * @since 1.00
 */
public class TagPanel extends Panel {
	/**
	 * Constructs and initialises a new TagPanel.
	 *
	 * @param label The label of this TagPanel (For example: "Class").
	 * @param listener The ActionListener for the buttons.
	 */
	public TagPanel(String label, ActionListener listener) {
		// Call the super method.
		super();

		// Set the LayoutManager to GridSpanLayout.
		setLayout(new GridSpanLayout(3, 6));

		// The GridSpanConstraints object we are going to use for constrained
		// adding.
		GridSpanConstraints constraints;

		// Add the tag label (title of this panel).
		// Make it use the first row.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(0);
		constraints.setWidth(3);
		constraints.setHeight(1);
		add(new Label(label + " Comment"), constraints);

		// Add the add checkbox.
		// Put it in the rightmost cell on the second row.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(1);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalAnchor(0.0);
		add(addcheckbox, constraints);

		// Add the convert checkbox.
		// Put it in the leftmost cell on the second row.
		constraints = new GridSpanConstraints();
		constraints.setX(1);
		constraints.setY(1);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalAnchor(0.0);
		add(convertcheckbox, constraints);

		// Add the Panel with the whiteline stuff on it.
		// Make is use the third row.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(2);
		constraints.setWidth(3);
		constraints.setHeight(1);
		constraints.setHorizontalAnchor(0.0);
		Panel whitelinepanel = new Panel(new FlowLayout(FlowLayout.LEFT, 0, 0));
		whitelinepanel.add(new Label("Add"));
		whitelinepanel.add(whitelines);
		whitelinepanel.add(new Label("   white lines"));
		add(whitelinepanel, constraints);

		// Add the tag List.
		// Make it use the fourth and fifth row, and the first and second column.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(3);
		constraints.setWidth(2);
		constraints.setHeight(2);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		add(taglist, constraints);

		// Add the Add button. Register listener as its actionlistener.
		// Put it in the upper cell next to the list.
		constraints = new GridSpanConstraints();
		constraints.setX(2);
		constraints.setY(3);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		Button addbutton = new Button("Add");
		addbutton.setActionCommand("ADD" + label.toUpperCase() + "TAG");
		addbutton.addActionListener(listener);
		add(addbutton, constraints);

		// Add the Remove button. Register listener as its actionlistener.
		// Put it in the lower cell next to the list.
		constraints = new GridSpanConstraints();
		constraints.setX(2);
		constraints.setY(4);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalFill(1.0);
		Button removebutton = new Button("Remove");
		removebutton.setActionCommand("REMOVE" + label.toUpperCase() + "TAG");
		removebutton.addActionListener(listener);
		add(removebutton, constraints);

		// Add the Move Up button. Register listener as its actionlistener.
		// Put it in the left cell under the list.
		constraints = new GridSpanConstraints();
		constraints.setX(0);
		constraints.setY(5);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalAnchor(0.0);
		Button moveupbutton = new Button("Up");
		moveupbutton.setActionCommand("MOVEUP" + label.toUpperCase() + "TAG");
		moveupbutton.addActionListener(listener);
		add(moveupbutton, constraints);

		// Add the Move Down button. Register listener as its actionlistener.
		// Put it in the right cell under the list.
		constraints = new GridSpanConstraints();
		constraints.setX(1);
		constraints.setY(5);
		constraints.setWidth(1);
		constraints.setHeight(1);
		constraints.setHorizontalFill(1.0);
		constraints.setVerticalAnchor(0.0);
		Button movedownbutton = new Button("Down");
		movedownbutton.setActionCommand("MOVEDOWN" + label.toUpperCase() + "TAG");
		movedownbutton.addActionListener(listener);
		add(movedownbutton, constraints);
	}


	/**
	 * Adds a tag to the tag list.
	 *
	 * @param tag The tag to be added.
	 */
	public void addTag(String tag) {
		// Add the tag to the list.
		taglist.add(tag);
	}

	/**
	 * Adds a tag to the tag list on the passed index.
	 *
	 * @param tag The tag to be added.
	 * @param index The index to add the passed tag on.
	 */
	public void addTag(String tag, int index) {
		// Add the tag to the list at the specified index.
		taglist.add(tag, index);
	}

	/**
	 * Removes a tag from the tag list.
	 *
	 * @param index The index of the tag to be removed.
	 */
	public void removeTag(int index) {
		// Check whether the index is in bounds. If it is not, we don't do anything.
		// Most likely no tag was selected then.
		if(index >= 0) {
			// Remove the tag from the list.
			taglist.remove(index);
		}
	}

	/**
	 * Returns the amount of tags.
	 *
	 * @return The amount of tags.
	 */
	public int getNumberOfTags() {
		// Return the amount of tags in the list.
		return taglist.getItemCount();
	}

	/**
	 * Returns the index of the currently selected tag.
	 *
	 * @return The index of the currently selected tag.
	 */
	public int getSelectedTagIndex() {
		// Return the index of the currently selected tag in the list.
		return taglist.getSelectedIndex();
	}

	/**
	 * Returns the currently selected tag.
	 *
	 * @return The currently selected tag.
	 */
	public String getSelectedTag() {
		// Return the currently selected tag in the list.
		return taglist.getSelectedItem();
	}

	/**
	 * Selects the tag at the passed index.
	 *
	 * @param index The index of the tag to be added.
	 */
	public void selectTag(int index) {
		// Tell the tag list to select the tag.
		taglist.select(index);
	}

	/**
	 * Returns the tags in the tag list.
	 *
	 * @return The tags in the tag list.
	 */
	public String[] getTags() {
		// Retrieve the items in the tag list and return them.
		return taglist.getItems();
	}


	/**
	 * Returns whether the user wants to have their comment converted.
	 *
	 * @return Whether the user wants to have their comment converted.
	 */
	public boolean getConvertComment() {
		// Retrieve the state of the checkbox and return it.
		return convertcheckbox.getState();
	}

	/**
	 * Returns whether the user wants to have comment added.
	 *
	 * @return Whether the user wants to have comment added.
	 */
	public boolean getAddComment() {
		// Retrieve the state of the checkbox and return it.
		return addcheckbox.getState();
	}

	/**
	 * Returns the amount of white lines the user wants after their comment.
	 *
	 * @return The amount of white lines the user wants after their comment.
	 */
	public String getWhiteLines() {
		// Retrieve the items in the tag list and return them.
		return whitelines.getText();
	}


	/**
	 * The checkbox where the user can indicate whether comment should be converted.
	 * Give it a label, and set it to be standard on.
	 */
	protected Checkbox convertcheckbox = new Checkbox("Convert", true);

	/**
	 * The checkbox where the user can indicate whether comment should be added.
	 * Give it a label, and set it to be standard on.
	 */
	protected Checkbox addcheckbox = new Checkbox("Add", true);

	/**
	 * The textfield where the user can indicate how many white lines he wants.
	 */
	protected TextField whitelines = new TextField("0");

	/**
	 * The list with the tags in it.
	 */
	protected List taglist = new List();
}