/*
 * Copyright 2003, 2004 Berend "Kirk" Wouda
 *
 * This file is part of JavaDoctor.
 *
 * JavaDoctor is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * JavaDoctor is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JavaDoctor; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// The package of this class. I think.
package system;

// Import the GUI event stuff.
import java.awt.event.*;

// Import our GUI classes.
import gui.*;

// Import the IO classes.
import java.io.*;

/**
 * This class does all the internal work that the GUI asks for.
 * It acts as the event listener for button pressing.
 *
 * @author Berend "Kirk" Wouda
 * @version 1.02
 * @since 1.00
 */
public class JDControl implements ActionListener {
	/**
	 * Constructs a new JDControl and associates it with the passed GUI.
	 *
	 * @param frame The GUI to associate with.
	 */
	public JDControl(JDFrame frame) {
		// Set the gui.
		gui = frame;
	}


	/**
	 * Gets called when an ActionEvent is generated.
	 *
	 * @param event The generated event.
	 */
	public void actionPerformed(ActionEvent event) {
		// A button has been pressed.
		// Retrieve the action command from the event.
		String command = event.getActionCommand();

		// Find out which button was pressed.
		// The List Files button.
		if(command.equals("LISTFILES"))  listFiles();
		// The Convert button.
		else if(command.equals("CONVERT"))  convert();
		// The Select All Files button.
		else if(command.equals("SELECTALL"))  selectAll();
		// The Deselect All Files button.
		else if(command.equals("SELECTNONE"))  selectNone();

		// The Add Class Tag button.
		else if(command.equals("ADDCLASSTAG"))  addClassTag();
		// The Remove Class Tag button.
		else if(command.equals("REMOVECLASSTAG"))  removeClassTag();
		// The Move Up Class Tag button.
		else if(command.equals("MOVEUPCLASSTAG"))  moveUpClassTag();
		// The Move Down Class Tag button.
		else if(command.equals("MOVEDOWNCLASSTAG"))  moveDownClassTag();

		// The Add Method Tag button.
		else if(command.equals("ADDMETHODTAG"))  addMethodTag();
		// The Remove Method Tag button.
		else if(command.equals("REMOVEMETHODTAG"))  removeMethodTag();
		// The Move Up Method Tag button.
		else if(command.equals("MOVEUPMETHODTAG"))  moveUpMethodTag();
		// The Move Down Method Tag button.
		else if(command.equals("MOVEDOWNMETHODTAG"))  moveDownMethodTag();

		// The Add Attribute Tag button.
		else if(command.equals("ADDATTRIBUTETAG"))  addAttributeTag();
		// The Remove Attribute Tag button.
		else if(command.equals("REMOVEATTRIBUTETAG"))  removeAttributeTag();
		// The Move Up Attribute Tag button.
		else if(command.equals("MOVEUPATTRIBUTETAG"))  moveUpAttributeTag();
		// The Move Down Attribute Tag button.
		else if(command.equals("MOVEDOWNATTRIBUTETAG"))  moveDownAttributeTag();

		// If we get here something is very wrong.
		else  gui.popup("Oh my god! This wasn't supposed to happen!");
	}

	/**
	 * Lists all the files in the input folder in the file list of gui.
	 */
	protected void listFiles() {
		// Retrieve the input folder and construct a File around it.
		File inputfolder = new File(gui.getInputFolder());

		// Check whether inputfolder actually is a folder.
		if(inputfolder.isDirectory()) {
			// Get the list of files, using a filenamefilter that only accept .java
			// files.
			String[] filelist = inputfolder.list(new JavaFilenameFilter());

			// Set the gui's list of files to this list of files.
			gui.setFileList(filelist);
		}
		// Input ain't no folder at all! Display an error message.
		else  gui.popup("Input Folder is not an existing folder. Please choose an existing folder.");
	}

	/**
	 * Converts the comments in the selected files into Javadoc comments.
	 */
	protected void convert() {
		// Catch errors...
		try {
			// Get the input folder from the GUI.
			String inputfolder = gui.getInputFolder();

			// The output folder from the GUI.
			String outputfolder;

			// Check whether the output folder is the same as the input folder, and set
			// it so, if so.
			if(gui.outputFolderIsInputFolder())  outputfolder = gui.getInputFolder();
			// If not, use the output folder setting.
			else  outputfolder = gui.getOutputFolder();

			// Check whether intputfolder and outputfolder are actual folders.
			if((new File(inputfolder)).isDirectory() && (new File(outputfolder)).isDirectory()) {
				// Get a list of the selected files from the GUI.
				String[] filelist = gui.getFileList();

				// Retrieve the JavaDoc style commenting. There are two types:
				//
				// /**
				//
				// */
				//
				// and
				//
				// /**
				//  *
				//  */
				//
				// Since there are 2, we'll indicate it with a boolean that indicates whether
				// or not the star insets are wanted.
				boolean starinsets = gui.getStarInsets();


				// Retrieve the tag options for the class comments.
				String[] classtags = gui.getClassTags();

				// Retrieve whether non-javadoc class comments are to be converted.
				boolean convertclasscomment = gui.getConvertClassComment();

				// Retrieve whether javadoc class comments are to be added to stuff that
				// doesn't have any.
				boolean addclasscomment = gui.getAddClassComment();

				// Retrieve the number of white lines that will in in added javadoc comment
				// for classes.
				int classwhitelines = Integer.parseInt(gui.getClassWhiteLines());


				// Retrieve the tag options for the method comments.
				String[] methodtags = gui.getMethodTags();

				// Retrieve whether non-javadoc method comments are to be converted.
				boolean convertmethodcomment = gui.getConvertMethodComment();

				// Retrieve whether javadoc method comments are to be added to stuff that
				// doesn't have any.
				boolean addmethodcomment = gui.getAddMethodComment();

				// Retrieve the number of white lines that will in in added javadoc comment
				// for methods.
				int methodwhitelines = Integer.parseInt(gui.getMethodWhiteLines());


				// Retrieve the tag options for the attribute comments. As of now, there are
				// none, I believe. But hey, who knows.
				String[] attributetags = gui.getAttributeTags();

				// Retrieve whether non-javadoc attribute comments are to be converted.
				boolean convertattributecomment = gui.getConvertAttributeComment();

				// Retrieve whether javadoc attribute comments are to be added to stuff that
				// doesn't have any.
				boolean addattributecomment = gui.getAddAttributeComment();

				// Retrieve the number of white lines that will in in added javadoc comment
				// for attributes.
				int attributewhitelines = Integer.parseInt(gui.getAttributeWhiteLines());


				// Go through the filename array...
				for(int index = 0; index < filelist.length; index++) {
					// ... and, per element, construct a new CommentConverter (with the
					// correct javadoc style).
					CommentConverter converter = new CommentConverter(inputfolder + System.getProperty("file.separator") + filelist[index], starinsets);

					// If requested, convert all the class comments for this class.
					if(convertclasscomment)  converter.convertClassComments(classtags);

					// If requested, add all the class comments for this class.
					if(addclasscomment)  converter.addClassComments(classtags, classwhitelines);

					// If requested, convert all the method comments for this class.
					if(convertmethodcomment)  converter.convertMethodComments(methodtags);

					// If requested, add all the method comments for this class.
					if(addmethodcomment)  converter.addMethodComments(methodtags, methodwhitelines);

					// If requested, convert all the attribute comments for this class.
					if(convertattributecomment)  converter.convertAttributeComments(attributetags);

					// If requested, add all the attribute comments for this class.
					if(addattributecomment)  converter.addAttributeComments(attributetags, attributewhitelines);

					// Before we move on to the next file, save the changes to this one.
					converter.save(outputfolder + System.getProperty("file.separator") + filelist[index]);
				}
			}
			// The folders are not real folders! Oh no! Display an error message.
			else  gui.popup("The Input or Output folder does not exist. Please make sure both folders exist.");

			// Pop up a message telling the user we're done.
			gui.popup("Convertion Completed!");
		}
		// An error has occured. It has to do with the file.
		catch(IOException e) {
			// Display the error message to the user.
			gui.popup("A file read or write error has occured with the current file: " + e.getMessage());
		}
		// An error has occured. It has to do with the fact that the user didn't
		// fill in a number at one of the white lines textfields.
		catch(NumberFormatException e) {
			// Display the error message to the user.
			gui.popup("You have to fill in a number in all the amount of white lines fields");
		}
		// An error has occured. It has to do with the fact that the java files
		// are too badly written for this program to understand ;)
		catch(Exception e) {
			// Display the error message to the user.
			gui.popup("An error has occured with the processing of the current file: " + e.getMessage());
		}
	}

	/**
	 * Selects all the files in the file list in gui.
	 */
	protected void selectAll() {
		// Tell the gui to select all the files.
		gui.selectAllFiles();
	}

	/**
	 * Deselects all the files in the file list in gui.
	 */
	protected void selectNone() {
		// Tell the gui to deselect all the files.
		gui.deselectAllFiles();
	}


	/**
	 * Adds the entered class tag to the list of class tags.
	 */
	protected void addClassTag() {
		// Tell the gui to pop up a box where the user can enter a tag.
		String tag = gui.getPopupText("Please enter a class tag:");

		// Get the selected index.
		int tagindex = gui.getSelectedClassTagIndex();

		// Check if the user typed something in.
		if(tag != null) {
			// Check whether a tag is selected.
			if(tagindex >= 0) {
				// Add the new tag on the next index.
				gui.addClassTag(tag, tagindex + 1);

				// Select it.
				gui.selectClassTag(tagindex + 1);
			}
			else {
				// Add it at the end.
				gui.addClassTag(tag);

				// Select it.
				gui.selectClassTag(gui.getNumberOfClassTags() - 1);
			}
		}
	}

	/**
	 * Removes the selected class tag from the list of class tags.
	 */
	protected void removeClassTag() {
		// The index of the currently selected class tag in the list.
		int tagindex = gui.getSelectedClassTagIndex();

		// Tell the gui to remove that tag.
		gui.removeClassTag(tagindex);

		// Check whether the index is not the last index.
		if(tagindex < gui.getNumberOfClassTags() - 1) {
			// Select the next tag. It's the one on the same position since the
			// previous one got removed.
			gui.selectClassTag(tagindex);
		}
		else {
			// Select the last tag.
			gui.selectClassTag(gui.getNumberOfClassTags() - 1);
		}
	}

	/**
	 * Moves the selected class tag up one in the list of class tags.
	 */
	protected void moveUpClassTag() {
		// Retrieve the index of the currently selected class tag, and the class tag
		// itself from gui.
		int tagindex = gui.getSelectedClassTagIndex();
		String classtag = gui.getSelectedClassTag();

		// Check whether the index is not the first index, and whether a tag is
		// selected, all in one!
		if(tagindex > 0) {
			// Remove the class tag at tagindex from the list.
			gui.removeClassTag(tagindex);

			// Add the class tag to the position above it last position.
			gui.addClassTag(classtag, tagindex - 1);

			// Finally, select it.
			gui.selectClassTag(tagindex - 1);
		}
	}

	/**
	 * Moves the selected class tag down one in the list of class tags.
	 */
	protected void moveDownClassTag() {
		// Retrieve the index of the currently selected class tag, and the class tag
		// itself from gui.
		int tagindex = gui.getSelectedClassTagIndex();
		String classtag = gui.getSelectedClassTag();

		// Check whether the index is not the last index, and whether there is a
		// tag selected.
		if(tagindex >= 0 && tagindex < gui.getNumberOfClassTags() - 1) {
			// Remove the class tag at tagindex from the list.
			gui.removeClassTag(tagindex);

			// Add the class tag to the position under it last position.
			gui.addClassTag(classtag, tagindex + 1);

			// Finally, select it.
			gui.selectClassTag(tagindex + 1);
		}
	}


	/**
	 * Adds the entered method tag to the list of method tags.
	 */
	protected void addMethodTag() {
		// Tell the gui to pop up a box where the user can enter a tag.
		String tag = gui.getPopupText("Please enter a method tag:");

		// Get the selected index.
		int tagindex = gui.getSelectedMethodTagIndex();

		// Check if the user typed something in.
		if(tag != null) {
			// Check whether a tag is selected.
			if(tagindex >= 0) {
				// Add the new tag on the next index.
				gui.addMethodTag(tag, tagindex + 1);

				// Select it.
				gui.selectMethodTag(tagindex + 1);
			}
			else {
				// Add it at the end.
				gui.addMethodTag(tag);

				// Select it.
				gui.selectMethodTag(gui.getNumberOfMethodTags() - 1);
			}
		}
	}

	/**
	 * Removes the selected method tag from the list of method tags.
	 */
	protected void removeMethodTag() {
		// The index of the currently selected method tag in the list.
		int tagindex = gui.getSelectedMethodTagIndex();

		// Tell the gui to remove that tag.
		gui.removeMethodTag(tagindex);

		// Check whether the index is not the last index.
		if(tagindex < gui.getNumberOfMethodTags() - 1) {
			// Select the next tag. It's the one on the same position since the
			// previous one got removed.
			gui.selectMethodTag(tagindex);
		}
		else {
			// Select the last tag.
			gui.selectMethodTag(gui.getNumberOfMethodTags() - 1);
		}
	}

	/**
	 * Moves the selected method tag up one in the list of method tags.
	 */
	protected void moveUpMethodTag() {
		// Retrieve the index of the currently selected method tag, and the method
		// tag itself from gui.
		int tagindex = gui.getSelectedMethodTagIndex();
		String methodtag = gui.getSelectedMethodTag();

		// Check whether the index is not the first index, and whether a tag is
		// selected, all in one!
		if(tagindex > 0) {
			// Remove the method tag at tagindex from the list.
			gui.removeMethodTag(tagindex);

			// Add the method tag to the position above it last position.
			gui.addMethodTag(methodtag, tagindex - 1);

			// Finally, select it.
			gui.selectMethodTag(tagindex - 1);
		}
	}

	/**
	 * Moves the selected method tag down one in the list of method tags.
	 */
	protected void moveDownMethodTag() {
		// Retrieve the index of the currently selected method tag, and the method
		// tag itself from gui.
		int tagindex = gui.getSelectedMethodTagIndex();
		String methodtag = gui.getSelectedMethodTag();

		// Check whether the index is not the last index, and whether there is a
		// tag selected.
		if(tagindex >= 0 && tagindex < gui.getNumberOfMethodTags() - 1) {
			// Remove the method tag at tagindex from the list.
			gui.removeMethodTag(tagindex);

			// Add the method tag to the position under it last position.
			gui.addMethodTag(methodtag, tagindex + 1);

			// Finally, select it.
			gui.selectMethodTag(tagindex + 1);
		}
	}


	/**
	 * Adds the entered attribute tag to the list of attribute tags.
	 */
	protected void addAttributeTag() {
		// Tell the gui to pop up a box where the user can enter a tag.
		String tag = gui.getPopupText("Please enter an attribute tag:");

		// Get the selected index.
		int tagindex = gui.getSelectedAttributeTagIndex();

		// Check if the user typed something in.
		if(tag != null) {
			// Check whether a tag is selected.
			if(tagindex >= 0) {
				// Add the new tag on the next index.
				gui.addAttributeTag(tag, tagindex + 1);

				// Select it.
				gui.selectAttributeTag(tagindex + 1);
			}
			else {
				// Add it at the end.
				gui.addAttributeTag(tag);

				// Select it.
				gui.selectAttributeTag(gui.getNumberOfAttributeTags() - 1);
			}
		}
	}

	/**
	 * Removes the selected attribute tag from the list of attribute tags.
	 */
	protected void removeAttributeTag() {
		// The index of the currently selected attribute tag in the list.
		int tagindex = gui.getSelectedAttributeTagIndex();

		// Tell the gui to remove that tag.
		gui.removeAttributeTag(tagindex);

		// Check whether the index is not the last index.
		if(tagindex < gui.getNumberOfAttributeTags() - 1) {
			// Select the next tag. It's the one on the same position since the
			// previous one got removed.
			gui.selectAttributeTag(tagindex);
		}
		else {
			// Select the last tag.
			gui.selectAttributeTag(gui.getNumberOfAttributeTags() - 1);
		}
	}

	/**
	 * Moves the selected method tag up one in the list of method tags.
	 */
	protected void moveUpAttributeTag() {
		// Retrieve the index of the currently selected attribute tag, and the
		// attribute tag itself from gui.
		int tagindex = gui.getSelectedAttributeTagIndex();
		String attributetag = gui.getSelectedAttributeTag();

		// Check whether the index is not the first index, and whether a tag is
		// selected, all in one!
		if(tagindex > 0) {
			// Remove the method tag at tagindex from the list.
			gui.removeAttributeTag(tagindex);

			// Add the method tag to the position above it last position.
			gui.addAttributeTag(attributetag, tagindex - 1);

			// Finally, select it.
			gui.selectAttributeTag(tagindex - 1);
		}
	}

	/**
	 * Moves the selected attribute tag down one in the list of attribute tags.
	 */
	protected void moveDownAttributeTag() {
		// Retrieve the index of the currently selected attribute tag, and the
		// attribute tag itself from gui.
		int tagindex = gui.getSelectedAttributeTagIndex();
		String attributetag = gui.getSelectedAttributeTag();

		// Check whether the index is not the last index, and whether there is a
		// tag selected.
		if(tagindex >= 0 && tagindex < gui.getNumberOfAttributeTags() - 1) {
			// Remove the attribute tag at tagindex from the list.
			gui.removeAttributeTag(tagindex);

			// Add the attribute tag to the position under it last position.
			gui.addAttributeTag(attributetag, tagindex + 1);

			// Finally, select it.
			gui.selectAttributeTag(tagindex + 1);
		}
	}


	/**
	 * The associated GUI.
	 */
	protected JDFrame gui;
}