/*
 * Copyright 2003, 2004 Berend "Kirk" Wouda
 *
 * This file is part of JavaDoctor.
 *
 * JavaDoctor is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * JavaDoctor is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JavaDoctor; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// The package of this class.
package system;

// Import the IO classes.
import java.io.*;

/**
 * This class is used for filtering out the correct filenames when getting the file
 * list with <code>File.list(new JavaFilenameFilter())</code>.
 *
 * @author Berend "Kirk" Wouda
 * @version 1.02
 * @since 1.00
 */
public class JavaFilenameFilter implements FilenameFilter {
	/**
	 * Returns true when the passed filename should be included in the listing,
	 * or false otherwise.
	 *
	 * @param dir The folder the file is in.
	 * @param name The name of the file.
	 * @see java.io.FilenameFilter#accept(java.io.File, java.lang.String)
	 */
	public boolean accept(File dir, String name) {
		// Check whether this file is a file and ends with .java.
		if(name.endsWith(".java") && !(new File(dir, name)).isDirectory())  return true;
		// These are not the droids you are looking for.
		else  return false;
	}
}